"""
fuzzyparsers library initialization
"""

from fuzzyparsers import *

# backwards compatibility function
sanitized_date = parse_date
